@@ -262,7 +262,7 @@ PFlashPixImageView::PFlashPixImageView (OLEStorage* theOwningStorage, const char
 
 //  ----------------------------------------------------------------------------
 // Open the file in Create Mode 
-PFlashPixImageView::PFlashPixImageView (FicNom& refName, long width, long height, float resolution,
+PFlashPixImageView::PFlashPixImageView (FicNom& refName, int width, int height, float resolution,
                   FPXBaselineColorSpace baseSpace, unsigned long backColor, 
                   FPXCompressionOption FPXCompressOption, Boolean createFPXImageView, Boolean baseUncalibrated)
                   : ViewImage(refName)
@@ -314,7 +314,7 @@ PFlashPixImageView::PFlashPixImageView (FicNom& refName, long width, long height
 
 //  ----------------------------------------------------------------------------
 // Open the file in Create Mode 
-PFlashPixImageView::PFlashPixImageView (OLEStorage* theOwningStorage, const char* theStorageName, long width, long height, float resolution,
+PFlashPixImageView::PFlashPixImageView (OLEStorage* theOwningStorage, const char* theStorageName, int width, int height, float resolution,
                   FPXBaselineColorSpace baseSpace, unsigned long backColor, 
                   FPXCompressionOption FPXCompressOption, Boolean createFPXImageView, Boolean baseUncalibrated)
                   : ViewImage()
@@ -564,7 +564,7 @@ FPXStatus PFlashPixImageView::OpenFile()
   height /= normalizationRatio;
   originWidth  /= normalizationRatio;
   originHeight /= normalizationRatio;
-  long pixWidth, pixHeight;
+  int pixWidth, pixHeight;
   image->GetTrueDimensions(&pixWidth,&pixHeight);
   float resolution = (float)(pixHeight) / (float)(1.0);
   image->SetImageSize(pixWidth,pixHeight,resolution);
@@ -807,7 +807,7 @@ FPXStatus PFlashPixImageView::MakeNewThumbnail ( OLEProperty *aProp)
   if ( CreateThumbnail((unsigned char *)thumbNail.Get32BitsBuffer(), tnailColorSpace, 
               (short)thumbNailWidth, (short)thumbNailHeight,&cf) )  {
     *aProp = (CLIPDATA *)&cf;
-    delete cf.pClipData; 
+    delete[] cf.pClipData; 
   }
   else 
     status = FPX_ERROR;
@@ -917,8 +917,8 @@ FPXStatus PFlashPixImageView::SaveSourcePropertySet()
   // PTCH_CACHEIMGSIZ - the size of the cached source image is required. If the size
   //  has not been set, then do so before saving.
   if ((imageDesc.heightIsValid == FALSE) || (imageDesc.widthIsValid == FALSE)) {
-    long  w = 0;
-    long  h = 0;
+    int  w = 0;
+    int  h = 0;
     if (image)
       image->GetDimensions (&w, &h);
     imageDesc.height = h;
@@ -1108,8 +1108,8 @@ void PFlashPixImageView::InitSourcePropertySet(FPXImageDescription* theImageDesc
   // Get the pixels dimensions of the source image
   theImageDesc->heightIsValid = TRUE;
   theImageDesc->widthIsValid  = TRUE;
-  long w = 0;
-  long h = 0;
+  int w = 0;
+  int h = 0;
   if (image)
     image->GetDimensions (&w, &h);
   theImageDesc->height = h;
@@ -1234,13 +1234,13 @@ FPXStatus PFlashPixImageView::SetGlobalInfoPropertySet(FPXGlobalInfo* theGlobalI
       *aProp = (FPXLongArray)(theGlobalInfo->visibleOutputs);
 
     if (filePtr->SetGlobalInfoProperty (PID_MaxImageIndex, TYP_MaxImageIndex, &aProp))
-      *aProp = (long)(theGlobalInfo->maxImageIndex);
+      *aProp = (int32_t)(theGlobalInfo->maxImageIndex);
 
     if (filePtr->SetGlobalInfoProperty (PID_MaxTransfoIndex, TYP_MaxTransfoIndex, &aProp))
-      *aProp = (long)(theGlobalInfo->maxTransformIndex);
+      *aProp = (int32_t)(theGlobalInfo->maxTransformIndex);
 
     if (filePtr->SetGlobalInfoProperty (PID_MaxOperatorIndex, TYP_MaxOperatorIndex, &aProp))
-      *aProp = (long)(theGlobalInfo->maxOperatorIndex);
+      *aProp = (int32_t)(theGlobalInfo->maxOperatorIndex);
 
     filePtr->Commit();
   } else
@@ -1280,13 +1280,13 @@ FPXStatus PFlashPixImageView::GetGlobalInfoPropertySet(FPXGlobalInfo* theGlobalI
       theGlobalInfo->visibleOutputs = (FPXLongArray)(*aProp);
 
     if (filePtr->GetGlobalInfoProperty (PID_MaxImageIndex, &aProp))
-      theGlobalInfo->maxImageIndex = (long)(*aProp);
+      theGlobalInfo->maxImageIndex = (int32_t)(*aProp);
 
     if (filePtr->GetGlobalInfoProperty (PID_MaxTransfoIndex, &aProp))
-      theGlobalInfo->maxTransformIndex = (long)(*aProp);
+      theGlobalInfo->maxTransformIndex = (int32_t)(*aProp);
 
     if (filePtr->GetGlobalInfoProperty (PID_MaxOperatorIndex, &aProp))
-      theGlobalInfo->maxOperatorIndex = (long)(*aProp);
+      theGlobalInfo->maxOperatorIndex = (int32_t)(*aProp);
   } else
     err = FPX_NOT_A_VIEW;
   
@@ -1319,7 +1319,7 @@ FPXStatus PFlashPixImageView::SetSourcePropertySet(FPXImageDescription* theSourc
 
     if (theSourceDescription->revisionNumberIsValid)
       if (filePtr->SetSourceDescProperty (PID_RevisionNumber, TYP_RevisionNumber, &aProp))
-        *aProp = (long)(theSourceDescription->revisionNumber);
+        *aProp = (int32_t)(theSourceDescription->revisionNumber);
 
     if (theSourceDescription->creationDateIsValid)
       if (filePtr->SetSourceDescProperty (PID_CreationTime, TYP_CreationTime, &aProp))
@@ -1334,12 +1334,12 @@ FPXStatus PFlashPixImageView::SetSourcePropertySet(FPXImageDescription* theSourc
         *aProp = (FPXWideStr)(theSourceDescription->creatingApplication);
 
     // PLEASE WINDOWS TESTER: the following line may be little endian/big endian dependent...
-    long longStatus = (theSourceDescription->status.existenceData << 16) | theSourceDescription->status.permission;
+    int32_t longStatus = (theSourceDescription->status.existenceData << 16) | theSourceDescription->status.permission;
     if (filePtr->SetSourceDescProperty (PID_Status, TYP_Status, &aProp))
-      *aProp = (long)(longStatus);
+      *aProp = (int32_t)(longStatus);
 
     if (filePtr->SetSourceDescProperty (PID_Creator, TYP_Creator, &aProp))
-      *aProp = (long)(theSourceDescription->creator);
+      *aProp = (int32_t)(theSourceDescription->creator);
 
 
     if (filePtr->SetSourceDescProperty (PID_Users, TYP_Users, &aProp))
@@ -1347,11 +1347,11 @@ FPXStatus PFlashPixImageView::SetSourcePropertySet(FPXImageDescription* theSourc
 
     if (theSourceDescription->heightIsValid)
       if (filePtr->SetSourceDescProperty (PID_CachedImageHeight, TYP_CachedImageHeight, &aProp))
-        *aProp = (long)(theSourceDescription->height);
+        *aProp = (int32_t)(theSourceDescription->height);
 
     if (theSourceDescription->widthIsValid)
       if (filePtr->SetSourceDescProperty (PID_CachedImageWidth, TYP_CachedImageWidth, &aProp))
-        *aProp = (long)(theSourceDescription->width);
+        *aProp = (int32_t)(theSourceDescription->width);
 
     filePtr->Commit();
   } else
@@ -1392,7 +1392,7 @@ FPXStatus PFlashPixImageView::GetSourcePropertySet(FPXImageDescription* theSourc
       theSourceDescription->lastModifierIsValid = FALSE;
 
     if (filePtr->GetSourceDescProperty (PID_RevisionNumber, &aProp)) {
-      theSourceDescription->revisionNumber = (long)(*aProp);
+      theSourceDescription->revisionNumber = (int32_t)(*aProp);
       theSourceDescription->revisionNumberIsValid = TRUE;
     } else
       theSourceDescription->revisionNumberIsValid = FALSE;
@@ -1416,26 +1416,26 @@ FPXStatus PFlashPixImageView::GetSourcePropertySet(FPXImageDescription* theSourc
       theSourceDescription->creatingApplicationIsValid = FALSE;
 
     if (filePtr->GetSourceDescProperty (PID_Status, &aProp)) {
-      long longStatus = (long)(*aProp);
+      int32_t longStatus = (int32_t)(*aProp);
       // PLEASE WINDOWS TESTER: the following line may be little endian/big endian dependent...
       theSourceDescription->status.existenceData = (FPXImageExistence)((longStatus) >> 16);
       theSourceDescription->status.permission    = (FPXImagePermission)((longStatus) & 0xFFFF);
     }
     
     if (filePtr->GetSourceDescProperty (PID_Creator, &aProp))
-      theSourceDescription->creator = (long)(*aProp);
+      theSourceDescription->creator = (int32_t)(*aProp);
 
     if (filePtr->GetSourceDescProperty (PID_Users, &aProp))
       theSourceDescription->users = (FPXLongArray)(*aProp);
 
     if (filePtr->GetSourceDescProperty (PID_CachedImageHeight, &aProp)) {
-      theSourceDescription->height = (long)(*aProp);
+      theSourceDescription->height = (int32_t)(*aProp);
       theSourceDescription->heightIsValid = TRUE;
     } else
       theSourceDescription->heightIsValid = FALSE;
 
     if (filePtr->GetSourceDescProperty (PID_CachedImageWidth, &aProp)) {
-      theSourceDescription->width = (long)(*aProp);
+      theSourceDescription->width = (int32_t)(*aProp);
       theSourceDescription->widthIsValid = TRUE;
     } else
       theSourceDescription->widthIsValid = FALSE;
@@ -1471,7 +1471,7 @@ FPXStatus PFlashPixImageView::SetResultPropertySet(FPXImageDescription* theResul
 
     if (theResultDescription->revisionNumberIsValid)
       if (filePtr->SetResultDescProperty (PID_RevisionNumber, TYP_RevisionNumber, &aProp))
-        *aProp = (long)(theResultDescription->revisionNumber);
+        *aProp = (int32_t)(theResultDescription->revisionNumber);
 
     if (theResultDescription->creationDateIsValid)
       if (filePtr->SetResultDescProperty (PID_CreationTime, TYP_CreationTime, &aProp))
@@ -1486,23 +1486,23 @@ FPXStatus PFlashPixImageView::SetResultPropertySet(FPXImageDescription* theResul
         *aProp = (FPXWideStr)(theResultDescription->creatingApplication);
 
     // PLEASE WINDOWS TESTER: the following line may be little endian/big endian dependent...
-    long longStatus = (theResultDescription->status.existenceData << 16) | theResultDescription->status.permission;
+    int32_t longStatus = (theResultDescription->status.existenceData << 16) | theResultDescription->status.permission;
     if (filePtr->SetResultDescProperty (PID_Status, TYP_Status, &aProp))
-      *aProp = (long)(longStatus);
+      *aProp = (int32_t)(longStatus);
 
     if (filePtr->SetResultDescProperty (PID_Creator, TYP_Creator, &aProp))
-      *aProp = (long)(theResultDescription->creator);
+      *aProp = (int32_t)(theResultDescription->creator);
 
     if (filePtr->SetResultDescProperty (PID_Users, TYP_Users, &aProp))
       *aProp = (FPXLongArray)(theResultDescription->users);
 
     if (theResultDescription->heightIsValid)
       if (filePtr->SetResultDescProperty (PID_CachedImageHeight, TYP_CachedImageHeight, &aProp))
-        *aProp = (long)(theResultDescription->height);
+        *aProp = (int32_t)(theResultDescription->height);
 
     if (theResultDescription->widthIsValid)
       if (filePtr->SetResultDescProperty (PID_CachedImageWidth, TYP_CachedImageWidth, &aProp))
-        *aProp = (long)(theResultDescription->width);
+        *aProp = (int32_t)(theResultDescription->width);
 
     filePtr->Commit();
   } else
@@ -1542,7 +1542,7 @@ FPXStatus PFlashPixImageView::GetResultPropertySet(FPXImageDescription* theResul
       theResultDescription->lastModifierIsValid = FALSE;
 
     if (filePtr->GetResultDescProperty (PID_RevisionNumber, &aProp)) {
-      theResultDescription->revisionNumber = (long)(*aProp);
+      theResultDescription->revisionNumber = (int32_t)(*aProp);
       theResultDescription->revisionNumberIsValid = TRUE;
     } else
       theResultDescription->revisionNumberIsValid = FALSE;
@@ -1566,26 +1566,26 @@ FPXStatus PFlashPixImageView::GetResultPropertySet(FPXImageDescription* theResul
       theResultDescription->creatingApplicationIsValid = FALSE;
 
     if (filePtr->GetResultDescProperty (PID_Status, &aProp)) {
-      long longStatus = (long)(*aProp);
+      int32_t longStatus = (int32_t)(*aProp);
       // PLEASE WINDOWS TESTER: the following line may be little endian/big endian dependent...
       theResultDescription->status.existenceData = (FPXImageExistence)((longStatus) >> 16);
       theResultDescription->status.permission    = (FPXImagePermission)((longStatus) & 0xFFFF);
     }
     
     if (filePtr->GetResultDescProperty (PID_Creator, &aProp))
-      theResultDescription->creator = (long)(*aProp);
+      theResultDescription->creator = (int32_t)(*aProp);
 
     if (filePtr->GetResultDescProperty (PID_Users, &aProp))
       theResultDescription->users = (FPXLongArray)(*aProp);
 
     if (filePtr->GetResultDescProperty (PID_CachedImageHeight, &aProp)) {
-      theResultDescription->height = (long)(*aProp);
+      theResultDescription->height = (int32_t)(*aProp);
       theResultDescription->heightIsValid = TRUE;
     } else
       theResultDescription->heightIsValid = FALSE;
 
     if (filePtr->GetResultDescProperty (PID_CachedImageWidth, &aProp)) {
-      theResultDescription->width = (long)(*aProp);
+      theResultDescription->width = (int32_t)(*aProp);
       theResultDescription->widthIsValid = TRUE;
     } else
       theResultDescription->widthIsValid = FALSE;
@@ -1624,7 +1624,7 @@ FPXStatus PFlashPixImageView::SetTransformPropertySet(FPXTransform* theTransform
 
     if (theTransform->revisionNumberIsValid)
       if (filePtr->SetTransformProperty (PID_RevisionNumber, TYP_RevisionNumber, &aProp))
-        *aProp = (long)(theTransform->revisionNumber);
+        *aProp = (int32_t)(theTransform->revisionNumber);
 
     if (theTransform->creationDateIsValid)
       if (filePtr->SetTransformProperty (PID_CreationTime, TYP_CreationTime, &aProp))
@@ -1645,7 +1645,7 @@ FPXStatus PFlashPixImageView::SetTransformPropertySet(FPXTransform* theTransform
       *aProp = (FPXLongArray)(theTransform->outputDataObjects);
 
     if (filePtr->SetTransformProperty (PID_OperationNumber, TYP_OperationNumber, &aProp))
-      *aProp = (long)(theTransform->operationNumber);
+      *aProp = (int32_t)(theTransform->operationNumber);
 
     filePtr->Commit();
   } else
@@ -1690,7 +1690,7 @@ FPXStatus PFlashPixImageView::GetTransformPropertySet(FPXTransform* theTransform
       theTransform->lastModifierIsValid = FALSE;
 
     if (filePtr->GetTransformProperty (PID_RevisionNumber, &aProp)) {
-      theTransform->revisionNumber = (long)(*aProp);
+      theTransform->revisionNumber = (int32_t)(*aProp);
       theTransform->revisionNumberIsValid = TRUE;
     } else
       theTransform->revisionNumberIsValid = FALSE;
@@ -1720,7 +1720,7 @@ FPXStatus PFlashPixImageView::GetTransformPropertySet(FPXTransform* theTransform
       theTransform->outputDataObjects = (FPXLongArray)(*aProp);
 
     if (filePtr->GetTransformProperty (PID_OperationNumber, &aProp))
-      theTransform->operationNumber = (long)(*aProp);
+      theTransform->operationNumber = (int32_t)(*aProp);
   } else
     err = FPX_NOT_A_VIEW;
 
