@@ -1,10 +1,10 @@
 //  ----------------------------------------------------------------------------
 //  MODULE    : PHierarchicalImage
-//  LANGUAGE  : C++ 
-//  CREATOR   : Philippe BOSSUT 
-//  CREAT. DATE : Tuesday, March 12, 1996 
-//  DESCRIPTION : 
-//  COMMENTS  : 
+//  LANGUAGE  : C++
+//  CREATOR   : Philippe BOSSUT
+//  CREAT. DATE : Tuesday, March 12, 1996
+//  DESCRIPTION :
+//  COMMENTS  :
 //    SCCSID          : @(#)ph_image.cpp  1.2 12:48:36 22 Jul 1997
 //  ----------------------------------------------------------------------------
 //  Copyright (c) 1999 Digital Imaging Group, Inc.
@@ -31,9 +31,9 @@
 #include  <math.h>
 #ifdef macintosh
 #  include  <Errors.h>
-#endif  
+#endif
+
 
-  
 #ifndef Debug_h
 #  include  "debug.h"
 #endif
@@ -81,14 +81,14 @@ inline float MIN(float a, float b, float c)
 {
   return MIN(a, MIN(b,c));
 }
-  
+
 //  ----------------------------------------------------------------------------
 //  Member Functions
 //  ----------------------------------------------------------------------------
 
 // Open a file in Create mode (compressed or uncompressed) :
 // CAUTION : the file is opened as long as necessary
-PHierarchicalImage::PHierarchicalImage (FicNom& refName, long width, long height, float resolution) : PRIImage (width, height, resolution)
+PHierarchicalImage::PHierarchicalImage (FicNom& refName, int width, int height, float resolution) : PRIImage (width, height, resolution)
 {
   Init ();        // Init the object
 
@@ -125,7 +125,7 @@ PHierarchicalImage::PHierarchicalImage (FicNom& refName, mode_Ouverture openMode
 //  ----------------------------------------------------------------------------
 // Open a file in Create mode (compressed or uncompressed) :
 // CAUTION : the file is opened as long as necessary
-PHierarchicalImage::PHierarchicalImage (int theFd, long width, long height, float resolution) 
+PHierarchicalImage::PHierarchicalImage (int theFd, int width, int height, float resolution)
   : PRIImage (width, height, resolution)
 {
   Init ();        // Init the object
@@ -195,7 +195,7 @@ void PHierarchicalImage::Init ()
   convolution   = Toolkit_Convolution();  // Default convolution mode
   filter    = 0;        // No custom convolution function for the moment
   automaticDecimation = true;       // Default is: yes, do decimation automatically
-  
+
   compression   = Toolkit_Compression();  // Default compression mode
   compressionHandle = NULL;       // Start with no compression handle
   handleSize    = 0;        // which size is then null
@@ -219,15 +219,15 @@ void PHierarchicalImage::Init ()
 
 
 //  ----------------------------------------------------------------------------
-FPXStatus PHierarchicalImage::SetTileParameter (long width, long height)
+FPXStatus PHierarchicalImage::SetTileParameter (int width, int height)
 {
   // Test parameters consistency
   assert((width>0) && (height>0));
-  
+
   tileWidth = MAX(width,height);
   tileSize = width * height * sizeof(Pixel);
   tileLineSize = width * sizeof(Pixel);
-  log2TileWidth = (long)(Toolkit_Log2(tileWidth));  
+  log2TileWidth = (int)(Toolkit_Log2(tileWidth));
   maskTileWidth = tileWidth - 1;
   return FPX_OK;
 }
@@ -267,7 +267,7 @@ void PHierarchicalImage::UpdateErrorCount()
   if (!Status()) {      // If error raised
     nbSubImages = 0;    // Invalid the image
     mode = mode_Lecture;  // Force mode to be read only
-  }   
+  }
 }
 
 
@@ -276,14 +276,14 @@ void PHierarchicalImage::UpdateErrorCount()
 FPXStatus PHierarchicalImage::OpenImage()
 {
   FPXStatus status = FPX_OK;
-  
+
   // Open the file if it hasn't been done yet
   if (filePtr == NULL) {
     status = OpenFile();
     // Init the size parameters according to the infos read into the file
     SetImageSize(width,height,resolution);
   }
-    
+
   if (firstSubImage == NULL && !Status()) {
     if (nbSubImages != 0)                     // The file is open en read or write mode
       CreateInitResolutionLevelList();            // Create and initialize the list of sub image reading the file "filePtr"
@@ -294,7 +294,7 @@ FPXStatus PHierarchicalImage::OpenImage()
       status = FPX_FILE_READ_ERROR;
     }
     // Initialize the array of pointers "subImages"
-    // LS 1/11/96: We initialize the field 'subImages' even on error; 
+    // LS 1/11/96: We initialize the field 'subImages' even on error;
     //         else, LP crashes when reading a compressed image without QuickTime installed
     InitResolutionLevelsTable();
   }
@@ -310,7 +310,7 @@ FPXStatus PHierarchicalImage::GetFileName (FicNom& refName)
   refName = fileName;
   return(FPX_OK);
 }
-      
+
 
 //  ----------------------------------------------------------------------------
 // Store "pix" in a buffer, write it if it's full and compute sub-image buffer if necessary
@@ -318,27 +318,27 @@ FPXStatus PHierarchicalImage::WriteLine (Pixel* pix, short plan)
 {
   Pixel   *source;
   FPXStatus status = FPX_OK;
-  
-  if (GtheSystemToolkit->interleaving == Interleaving_Pixel) 
+
+  if (GtheSystemToolkit->interleaving == Interleaving_Pixel)
     status = firstSubImage->WriteLine(pix, plan);
   else {
     FastAllocArray(source,Pixel,(unsigned int)(width));
     if (source == NULL)
       return FPX_MEMORY_ALLOCATION_FAILED;
-      
+
     if ((GtheSystemToolkit->interleaving != Interleaving_Channel) || (plan == ActiveChannel_All)) {
       if (Toolkit_UnInterleave (pix, source, width, 1, width, 1)) {
         FastDeleteArray(source,Pixel);
         return FPX_COLOR_CONVERSION_ERROR;  // error converting pixel buffer according to user's options
       }
-  
+
     } else {
       // The buffer contain only the active channel
       // we must create a temporary buffer to send to the image file
-      register long j;
+      register int j;
       register unsigned char *src, *dst;
-      
-      src = (unsigned char *)(pix); 
+
+      src = (unsigned char *)(pix);
       dst = (unsigned char *)(source)  + plan;
       for (j = 0; j < width; j++, src++, dst+=sizeof(Pixel))
         *dst = *src;
@@ -352,29 +352,29 @@ FPXStatus PHierarchicalImage::WriteLine (Pixel* pix, short plan)
 
 //  ----------------------------------------------------------------------------
 // Store "pix" in a buffer, write it if it's full and compute sub-image buffer if necessary
-FPXStatus PHierarchicalImage::WriteRectangle (long x0, long y0, long x1, long y1, Pixel* pix, short plan, short resolution)
+FPXStatus PHierarchicalImage::WriteRectangle (int x0, int y0, int x1, int y1, Pixel* pix, short plan, short resolution)
 {
   FPXStatus status = FPX_OK;
-  
+
   if ( GtheSystemToolkit->interleaving == Interleaving_Pixel) {
     status = subImages[resolution]->WriteRectangle (x0, y0, x1, y1, pix, plan);
   } else {
-    long pixWidth = (x1 - x0 + 1);    // width of the buffer 'pix'
-    long pixHeight = (y1 - y0 + 1);   // height of the buffer 'pix'
+    int pixWidth = (x1 - x0 + 1);    // width of the buffer 'pix'
+    int pixHeight = (y1 - y0 + 1);   // height of the buffer 'pix'
     Pixel*  dest = NULL;        // temporary buffer
     Pixel*  ptrDest = NULL;
-    long subX0, subY0, subX1, subY1;  // corners of the temporary buffer
-    long bufSize = 0;         // size of temporary buffer
-    long bufWidth, bufHeight;     // width ans height of temporary buffer
-    register long i, j;
+    int subX0, subY0, subX1, subY1;  // corners of the temporary buffer
+    int bufSize = 0;         // size of temporary buffer
+    int bufWidth, bufHeight;     // width ans height of temporary buffer
+    register int i, j;
     register unsigned char *src, *dst, *ptrPix;
-    
+
     src = dst = ptrPix = 0;
-    // cut the rectangle in sub-rectangles to avoid to create a big buffer 
+    // cut the rectangle in sub-rectangles to avoid to create a big buffer
     // in memory when converting the interleaving.
     // These sub-rectangles have the size of a tile because writing tiles is optimum.
-    long incrRow = tileWidth;
-    long incrCol = tileWidth;
+    int incrRow = tileWidth;
+    int incrCol = tileWidth;
     for (subY0 = y0; subY0 <= y1; subY0+=incrRow) {
       subY1 = subY0 + incrRow-1;
       if (subY1 > y1) subY1 = y1;
@@ -413,12 +413,12 @@ FPXStatus PHierarchicalImage::WriteRectangle (long x0, long y0, long x1, long y1
         } else {
           // The buffer contain only the active channel
           // we must copy only this channel to the temporary buffer to send to the image file
-          
-          ptrPix = (unsigned char *)(pix); 
+
+          ptrPix = (unsigned char *)(pix);
           ptrPix += (subY0-y0)*pixWidth + (subX0-x0);
-          ptrDest = dest; 
+          ptrDest = dest;
           for (i=subY0;i<=subY1;i++,ptrDest+=bufWidth,ptrPix+=pixWidth ) {
-            src = ptrPix; 
+            src = ptrPix;
             dst = (unsigned char *)(ptrDest)  + plan;
             for (j=subX0; j<=subX1;j++,src++,dst+=sizeof(Pixel))
               *dst = *src;
@@ -432,12 +432,12 @@ FPXStatus PHierarchicalImage::WriteRectangle (long x0, long y0, long x1, long y1
         }
       }
     }
-  
+
     FastDeleteArray(dest,Pixel);
     dest = NULL;
   }
   return status;
-  
+
 }
 
 
@@ -452,7 +452,7 @@ FPXStatus PHierarchicalImage::RegenerateHierarchy ()
 
   // Required to have the recursion working
   SetAutomaticDecimation(true);
-  
+
   // Save any changes to the full resolution's tiles and then decimate it's tiles.
   if (firstSubImage) {
     err = firstSubImage->FlushModifiedTiles();
@@ -468,11 +468,11 @@ FPXStatus PHierarchicalImage::RegenerateHierarchy ()
 
 //  ----------------------------------------------------------------------------
 // Read a rectangle in the correct resolution level and fill 'pix' with it
-FPXStatus PHierarchicalImage::ReadRectangle (long x0, long y0, long x1, long y1, Pixel* pix, long resolution)
+FPXStatus PHierarchicalImage::ReadRectangle (int x0, int y0, int x1, int y1, Pixel* pix, int resolution)
 {
   FPXStatus status = FPX_OK;
   FPXStatus   currentStatus;
-  
+
   if (resolution == -1)
     resolution = 0;
   if (GtheSystemToolkit->interleaving == Interleaving_Pixel)
@@ -481,19 +481,19 @@ FPXStatus PHierarchicalImage::ReadRectangle (long x0, long y0, long x1, long y1,
     // Cut the rectangle in sub-rectangles to avoid to create a big buffer in memory
     // when converting the interleaving.
     // These sub-rectangles have the size of a tile because it's optimum.
-    long pixWidth = (x1 - x0 + 1);    // width of the buffer 'pix'
-    long pixHeight = (y1 - y0 + 1);   // height of the buffer 'pix'
+    int pixWidth = (x1 - x0 + 1);    // width of the buffer 'pix'
+    int pixHeight = (y1 - y0 + 1);   // height of the buffer 'pix'
     Pixel*  source = NULL;      // temporary buffer
     Pixel*  ptrSource = NULL;
-    long subX0, subY0, subX1, subY1;  // corners of the temporary buffer
-    long bufSize = 0;         // size of temporary buffer
-    long bufWidth, bufHeight;     // width ans height of temporary buffer
-    register long i, j;
+    int subX0, subY0, subX1, subY1;  // corners of the temporary buffer
+    int bufSize = 0;         // size of temporary buffer
+    int bufWidth, bufHeight;     // width ans height of temporary buffer
+    register int i, j;
     register unsigned char *src, *dst, *ptrPix;
-    
+
     short plan = Toolkit_ActiveChannel();
-    long incrRow = tileWidth;
-    long incrCol = tileWidth;
+    int incrRow = tileWidth;
+    int incrCol = tileWidth;
     for (subY0 = y0; subY0 <= y1; subY0+=incrRow) {
       subY1 = subY0 + incrRow-1;
       if (subY1 > y1) subY1 = y1;
@@ -523,12 +523,12 @@ FPXStatus PHierarchicalImage::ReadRectangle (long x0, long y0, long x1, long y1,
               status = FPX_MEMORY_ALLOCATION_FAILED;
           } else {
             // Pixel by pixel if planes specified, the destination contains only the choosen channel
-            ptrPix  = (unsigned char *)(pix); 
+            ptrPix  = (unsigned char *)(pix);
             ptrPix += (subY0-y0)*pixWidth + (subX0-x0);
-            ptrSource = source; 
+            ptrSource = source;
             for (i = subY0; i <= subY1; i++, ptrSource += bufWidth, ptrPix += pixWidth ) {
               src = (unsigned char *)(ptrSource)  + plan;
-              dst = ptrPix; 
+              dst = ptrPix;
               for (j = subX0; j <= subX1; j++, src += sizeof(Pixel), dst++)
                 *dst = *src;
             }
@@ -551,7 +551,7 @@ FPXStatus PHierarchicalImage::ReadRectangle (long x0, long y0, long x1, long y1,
 //  ----------------------------------------------------------------------------
 // Read the path from the Image file: this function has to be derived to really write the things in
 // the file. The following code handle only the memory management part.
-OSErr PHierarchicalImage::ReadPaths (data_Record** thePath, long* nbRecords, long* theClipPathNum)
+OSErr PHierarchicalImage::ReadPaths (data_Record** thePath, int* nbRecords, int* theClipPathNum)
 {
   return PRIImage::ReadPaths (thePath, nbRecords, theClipPathNum);
 }
@@ -560,26 +560,26 @@ OSErr PHierarchicalImage::ReadPaths (data_Record** thePath, long* nbRecords, lon
 //  ----------------------------------------------------------------------------
 // Write the path in the Image file: this function has to be derived to really write the things in
 // the file. The following code handle only the memory management part.
-OSErr PHierarchicalImage::WritePaths (data_Record*  thePath, long  nbRecords, long  theClipPathNum)
+OSErr PHierarchicalImage::WritePaths (data_Record*  thePath, int  nbRecords, int  theClipPathNum)
 {
   OSErr  err = noErr;
 
   // Release the old path if any
   ReleasePaths ();
-  
+
   // Store the new path info
   nbPaths   = nbRecords;
   clipPathNum = theClipPathNum;
-  
+
   // Allocate the intermediate path buffer
   if ((path = new data_Record [nbPaths]) == NULL) {
     err = memFullErr;   // error : can't reserve buffer
     goto end;
   }
-  
+
   // Copy the given paths into the allocated path buffer
   BlockMove(thePath,path,nbPaths*sizeof(data_Record));
-  
+
  end:
   if (err != noErr)
     // If error, clean everything before exit
@@ -589,17 +589,17 @@ OSErr PHierarchicalImage::WritePaths (data_Record*  thePath, long  nbRecords, lo
 
 
 //  ----------------------------------------------------------------------------
-FPXStatus PHierarchicalImage::Read4Points (long x0, long y0, long x1, long y1, long x2, long y2, long x3, long y3, Pixel* table, long levelSubImage)
+FPXStatus PHierarchicalImage::Read4Points (int x0, int y0, int x1, int y1, int x2, int y2, int x3, int y3, Pixel* table, int levelSubImage)
 {
   FPXStatus status = FPX_OK;        // Returned value
-  long    dx, dy;
-  long    n;
-  long    px[16], py[16];
+  int    dx, dy;
+  int    n;
+  int    px[16], py[16];
 
 
   dx = x1 - x0;
   dy = y1 - y0;
-  
+
   // Compute sub-image level
   if (levelSubImage != -1)
     n = levelSubImage;
@@ -622,14 +622,14 @@ FPXStatus PHierarchicalImage::Read4Points (long x0, long y0, long x1, long y1, l
         x1 >>= n; y1 >>= n;
         x0 >>= n; y0 >>= n;
       }
-    
+
       // Shift by half a pixel toward top left corner (origin): necessary to avoid misregistration when switching
       // between with and without interpolation (classic difference between discrete and continuous coordinates)
       x0 -= 2048; y0 -= 2048;   // Coordinates are with 12 bits precision, so 1 pixel = 4096 units...
-      x1 -= 2048; y1 -= 2048; 
-      x2 -= 2048; y2 -= 2048; 
-      x3 -= 2048; y3 -= 2048; 
-    
+      x1 -= 2048; y1 -= 2048;
+      x2 -= 2048; y2 -= 2048;
+      x3 -= 2048; y3 -= 2048;
+
       px[P00] = x0 >> 4;          py[P00] = y0 >> 4;
       dx = (x0+x3) >>1;         dy = (y0+y3) >>1;
       px[P22] = dx >>4;         py[P22] = dy >>4;
@@ -637,22 +637,22 @@ FPXStatus PHierarchicalImage::Read4Points (long x0, long y0, long x1, long y1, l
       px[P33] = (x3+dx)>>5;       py[P33] = (y3+dy)>>5;
       px[P31] = (x1+dx)>>5;       py[P31] = (y1+dy)>>5;
       px[P13] = (x2+dx)>>5;       py[P13] = (y2+dy)>>5;
-    
-      px[P32] = ((x3 += (x0 + x3)) + x1) >> 6;  py[P32] = ((y3 += (y0 + y3)) + y1) >> 6;    
+
+      px[P32] = ((x3 += (x0 + x3)) + x1) >> 6;  py[P32] = ((y3 += (y0 + y3)) + y1) >> 6;
       px[P23] = (x3 + x2) >> 6;   py[P23] = (y3 + y2) >> 6;
-        
+
       x3 = (x0 + x1) >> 1;        y3 = (y0 + y1) >> 1;
       px[P20] = x3 >> 4;          py[P20] = y3 >> 4;
       px[P21] = (x3+dx)>>5;       py[P21] = (y3+dy)>>5;
       px[P10] = (x0+x3)>>5;       py[P10] = (y0+y3)>>5;
       px[P30] = (x1+x3)>>5;       py[P30] = (y1+y3)>>5;
-    
+
       x3 = (x0 + x2) >> 1;        y3 = (y0 + y2) >> 1;
       px[P02] = x3 >> 4;          py[P02] = y3 >> 4;
       px[P12] = (x3+dx)>>5;       py[P12] = (y3+dy)>>5;
       px[P01] = (x0+x3)>>5;       py[P01] = (y0+y3)>>5;
       px[P03] = (x2+x3)>>5;       py[P03] = (y2+y3)>>5;
-      
+
       status = subImages[n]->ReadInterpolated (px, py, table);
     }
     else {
@@ -672,16 +672,16 @@ FPXStatus PHierarchicalImage::Read4Points (long x0, long y0, long x1, long y1, l
       px[P33] = (x3+dx)>>13;        py[P33] = (y3+dy)>>13;
       px[P31] = (x1+dx)>>13;        py[P31] = (y1+dy)>>13;
       px[P13] = (x2+dx)>>13;        py[P13] = (y2+dy)>>13;
-    
-      px[P32] = ((x3 += (x0 + x3)) + x1) >> 14; py[P32] = ((y3 += (y0 + y3)) + y1) >> 14;   
+
+      px[P32] = ((x3 += (x0 + x3)) + x1) >> 14; py[P32] = ((y3 += (y0 + y3)) + y1) >> 14;
       px[P23] = (x3 + x2) >> 14;    py[P23] = (y3 + y2) >> 14;
-        
+
       x3 = (x0 + x1) >> 1;        y3 = (y0 + y1) >> 1;
       px[P20] = x3 >> 12;         py[P20] = y3 >> 12;
       px[P21] = (x3+dx)>>13;        py[P21] = (y3+dy)>>13;
       px[P10] = (x0+x3)>>13;        py[P10] = (y0+y3)>>13;
       px[P30] = (x1+x3)>>13;        py[P30] = (y1+y3)>>13;
-    
+
       x3 = (x0 + x2) >> 1;        y3 = (y0 + y2) >> 1;
       px[P02] = x3 >> 12;         py[P02] = y3 >> 12;
       px[P12] = (x3+dx)>>13;        py[P12] = (y3+dy)>>13;
@@ -691,7 +691,7 @@ FPXStatus PHierarchicalImage::Read4Points (long x0, long y0, long x1, long y1, l
     }
   } else
     status = FPX_FILE_READ_ERROR;
-    
+
   if (status != FPX_OK) {
     // If the tile is missing, fill "table[]" with a chessboard pattern
     Pixel* ptp = table;
@@ -701,23 +701,23 @@ FPXStatus PHierarchicalImage::Read4Points (long x0, long y0, long x1, long y1, l
     *ptp++ = 0xFFFFFFFF; *ptp++ = 0xFFFFFFFF; *ptp++ = 0x00000000; *ptp++ = 0x00000000;
     *ptp++ = 0xFFFFFFFF; *ptp++ = 0xFFFFFFFF; *ptp++ = 0x00000000; *ptp++ = 0x00000000;
   }
-  
+
   return status;
 }
 
 
 //  ----------------------------------------------------------------------------
 // Send back the smallest image contained in a rectangle width * height.
-// Read it on disk if necessary. 
+// Read it on disk if necessary.
 // If decompressor is missing, send back NULL.
 // CAUTION : bufferOut must be allocated and freed by calling routine
 // CAUTION : we allocate a temporary buffer with pixelsPerLine*height pixels
-FPXStatus PHierarchicalImage::ReadInARectangle (Pixel* bufferOut, short pixelsPerLine, short rectWidth, short rectHeight, 
+FPXStatus PHierarchicalImage::ReadInARectangle (Pixel* bufferOut, short pixelsPerLine, short rectWidth, short rectHeight,
                   const CorrectLut* correctLut, Boolean useAlphaChannel, const CombinMat* combinaisonMatrix)
 {
   Pixel *bufferTemp, *ptrBufferTemp, *ptrBufferOut;
-  register long i;
-  
+  register int i;
+
   // allocate an intermediate buffer to read the rectangle
   unsigned int size = (unsigned int)(pixelsPerLine * rectHeight);
   FastAllocArray(bufferTemp,Pixel,size);
@@ -727,13 +727,13 @@ FPXStatus PHierarchicalImage::ReadInARectangle (Pixel* bufferOut, short pixelsPe
   ptrBufferOut = bufferOut;
   for (i = 0; i < rectHeight; i++, ptrBufferTemp += pixelsPerLine, ptrBufferOut += pixelsPerLine )
     memcpy(ptrBufferTemp, ptrBufferOut, pixelsPerLine*sizeof(Pixel));
-    
+
   // search the corresponding sub-image and call 'ReadInARectangle()' on this sub-image
   FPXStatus status = FPX_OK;
   if (nbSubImages) {
     i = 0;          // Start from the high resolution
-    long iWidth  = width; // Width  of the high res in pixels
-    long iHeight = height;  // Height of the high res in pixels
+    int iWidth  = width; // Width  of the high res in pixels
+    int iHeight = height;  // Height of the high res in pixels
     while ((iHeight >= rectHeight) && (iWidth >= rectWidth) && (i <= (nbSubImages-1))) {
       iHeight = (iHeight + 1)/2;
       iWidth  = (iWidth  + 1)/2;
@@ -743,16 +743,16 @@ FPXStatus PHierarchicalImage::ReadInARectangle (Pixel* bufferOut, short pixelsPe
       i -= 1;
     subImages[i]->ReadInARectangle(bufferTemp, pixelsPerLine, rectWidth, rectHeight, correctLut, useAlphaChannel, combinaisonMatrix);
   }
-  
+
   short plan = Toolkit_ActiveChannel();
   if ((plan != ActiveChannel_All) && (GtheSystemToolkit->interleaving == Interleaving_Channel)) {
     // Copy Pixel by pixel if planes specified, the destination contains only the choosen channel
-    register long j;
+    register int j;
     register unsigned char *src, *dst, *ptrCharBufferOut;
     ptrCharBufferOut = (unsigned char *)(bufferOut);
     for (i = 0; i < rectHeight; i++, bufferTemp += pixelsPerLine, ptrCharBufferOut += pixelsPerLine ) {
       src = (unsigned char *)(bufferTemp)  + plan;
-      dst = ptrCharBufferOut; 
+      dst = ptrCharBufferOut;
       for (j = 0; j < pixelsPerLine; j++, src += sizeof(Pixel), dst++)
         *dst = *src;
     }
@@ -774,19 +774,19 @@ FPXStatus PHierarchicalImage::ReadInARectangle (Pixel* bufferOut, short pixelsPe
 
 //  ----------------------------------------------------------------------------
 // Read size of full resolution image and size of tiles
-FPXStatus PHierarchicalImage::GetInfo (long* width, long* height, long* tileWidth, long* tileHeight, Typ_Compression* compr)
+FPXStatus PHierarchicalImage::GetInfo (int* width, int* height, int* tileWidth, int* tileHeight, Typ_Compression* compr)
 {
   *width  = this->width;
   *height = this->height;
   *tileWidth  = this->tileWidth;
   *tileHeight = this->tileWidth;
   *compr  = this->compression;
-      
+
   return FPX_OK;
 }
 
 //  ----------------------------------------------------------------------------
-FPXStatus PHierarchicalImage::GetTileSize (long* tileSize)
+FPXStatus PHierarchicalImage::GetTileSize (int* tileSize)
 {
   *tileSize = this->tileSize;
   return FPX_OK;
@@ -805,12 +805,12 @@ void* PHierarchicalImage::GetCurrentFile()
 Boolean PHierarchicalImage::EnoughDiskSpace ()
 {
   Boolean enoughSpace = true;
-  long channelNumber;
+  int channelNumber;
   float compressorRatio;
   return true;
-  
+
   channelNumber = GetNbChannel(baseSpace);
-  
+
   switch (compression) {
   case Compression_None:
     compressorRatio = (float) 1.0;
@@ -836,11 +836,11 @@ Boolean PHierarchicalImage::EnoughDiskSpace ()
     compressorRatio = (float) 1.0;
     break;
   }
-  
-  long size = (long) (((float)(width * height * channelNumber * compressorRatio * 4 / 3)/1024.0));
+
+  int size = (int) (((float)(width * height * channelNumber * compressorRatio * 4 / 3)/1024.0));
 
   enoughSpace = fileName.EnoughFreeSpace(size);
-  
+
   return enoughSpace;
 }
 
@@ -852,7 +852,7 @@ Boolean PHierarchicalImage::SetAlphaChannel(Boolean exist)
   PRIImage::SetAlphaChannel(exist);
   return (ExistAlphaChannel() ? EnoughDiskSpace() : true);
 }
-  
+
 //  ----------------------------------------------------------------------------
 // Set the decimation type when computing a subresolution
 void PHierarchicalImage::SetConvolution (Typ_Convolution newConvolution)
@@ -898,17 +898,17 @@ void PHierarchicalImage::SetBaseColorSpace (FPXBaselineColorSpace colorSpace)
 //  ----------------------------------------------------------------------------
 FPXStatus PHierarchicalImage::InverseAlpha ()
 {
-  for (long i = 0; i < nbSubImages; ++i)
+  for (int i = 0; i < nbSubImages; ++i)
     subImages[i]->InverseAlpha();
   return FPX_OK;
 }
 
 
 //  ----------------------------------------------------------------------------
-// Read a pixel of a sub image. Read it on disk if necessary. 
+// Read a pixel of a sub image. Read it on disk if necessary.
 // If error, return false and pixel is set to 0.
 // CAUTION : coordinates must be discrete with 12 bits precision (1 << 12).
-FPXStatus PHierarchicalImage::ReadMean (long xi, long yi, Pixel& pix, long levelSubImage)
+FPXStatus PHierarchicalImage::ReadMean (int xi, int yi, Pixel& pix, int levelSubImage)
 {
   FPXStatus status = FPX_OK;
 
@@ -936,10 +936,10 @@ FPXStatus PHierarchicalImage::ReadMean (long xi, long yi, Pixel& pix, long level
       // Read the pixel
       status = subImages[levelSubImage]->ReadMean (xi >> levelSubImage, yi >> levelSubImage, pix);
     }
-    
+
   } else
     pix = backgroundUsed;
-    
+
   return status;
 }
 
@@ -950,26 +950,26 @@ FPXStatus PHierarchicalImage::ReadMean (long xi, long yi, Pixel& pix, long level
 // another, one can say that if the pixels are equal, there is no dispersion of the alpha channel, otherwise
 // there is some. That way, we avoid effective dispersion computation.
 // CAUTION : coordinates must be discrete with 12 bits precision (1 << 12).
-Boolean PHierarchicalImage::DispersionAlphaChannel (long xNW,
-                                                    long yNW,
-                                                    long /*xNE*/,
-                                                    long /*yNE*/,
-                                                    long /*xSW*/,
-                                                    long /*ySW*/,
-                                                    long xSE,
-                                                    long ySE,
-                                                    long levelSubImage)
+Boolean PHierarchicalImage::DispersionAlphaChannel (int xNW,
+                                                    int yNW,
+                                                    int /*xNE*/,
+                                                    int /*yNE*/,
+                                                    int /*xSW*/,
+                                                    int /*ySW*/,
+                                                    int xSE,
+                                                    int ySE,
+                                                    int levelSubImage)
 {
   Boolean dispersion = false;
-  
+
   if ((Status() == 0) && nbSubImages) {
-  
+
     /*    The following is the full dispersion algorithm. More computation but less I/O...
- 
+
     Pixel pix[16];
     // Read the sample
     Boolean status = Read4Points(xNW, yNW, xNE, yNE, xSW, ySW, xSE, ySE, pix, levelSubImage);
-    
+
     if (status) {
                 // Compute the dispersion with the usual algorithm (see CommandeQ2.cp for explanation)
                 unsigned char alphaMax = pix[0].alpha;
@@ -979,7 +979,7 @@ Boolean PHierarchicalImage::DispersionAlphaChannel (long xNW,
                 alphaMin |= pix[i].alpha;
                 }
                 dispersion = (alphaMin ^ alphaMax);
-      
+
                 if (!dispersion) {
         // Check if we are on the border to avoid interpolation with the outside of the image
         Boolean onBorder = false;
@@ -1014,33 +1014,33 @@ Boolean PHierarchicalImage::DispersionAlphaChannel (long xNW,
     nextLevel = levelSubImage + 2;
     if (nextLevel >= nbSubImages)
       nextLevel = nbSubImages - 1;
-    
+
     if (levelSubImage != nextLevel) {
       // Read the pixels in each level
       Pixel pix0, pix1;
       Boolean status  = subImages[levelSubImage]->ReadMean (xi >> levelSubImage, yi >> levelSubImage, pix0);
       status &= subImages[nextLevel]->ReadMean (xi >> nextLevel, yi >> nextLevel, pix1);
-      
+
       // Compare them and estimate the dispersion value
       dispersion = status && !(pix0.alpha == pix1.alpha);
 
       // Comparision for the border pixels: the alpha channel outside the image is supposed to be null, so
       // if the pixel is on the border and is not null, there is a dispersion with the outside of the image.
       dispersion |= ((subImages[nextLevel]->IsOnTheBorder(xi >> nextLevel, yi >> nextLevel)) && pix1.alpha);
-    }   
+    }
   }
-  
+
   return dispersion;
 }
 
 
 //  ----------------------------------------------------------------------------
 // Read a rectangle (x0,y0,x1,y1: coordinates at full resolution) in a map
-// The correct sub image is read and sampled in order to fill the map with the rectangle 
+// The correct sub image is read and sampled in order to fill the map with the rectangle
 // CAUTION : map must be allocated and freed by calling routine
-FPXStatus PHierarchicalImage::ReadSampledRectangle(long x0, long y0,long x1, long y1, Pixel* map, short pixelsPerLine, long mapWidth, long mapHeight, Boolean showAlphaChannel, float ratio)
+FPXStatus PHierarchicalImage::ReadSampledRectangle(int x0, int y0, int x1, int y1, Pixel* map, short pixelsPerLine, int mapWidth, int mapHeight, Boolean showAlphaChannel, float ratio)
 {
-  
+
   if (ratio == 0.0){
     if (mapWidth <= MIN((float) mapHeight,(float) (x1-x0),(float) (y1-y0)) ) {
       if ( ABS(float(float(mapWidth) - float(x1-x0)*float(mapHeight)/float(y1-y0))) > 1.0) {
@@ -1065,21 +1065,21 @@ FPXStatus PHierarchicalImage::ReadSampledRectangle(long x0, long y0,long x1, lon
     }
     ratio = MIN(float(float(mapWidth)/float(x1 - x0)) , float(float(mapHeight)/float(y1 - y0)));
   }
-    
+
   if (nbSubImages) {
     long i;
-    
+
     for (i = nbSubImages-1; i>0; --i)
       if ((subImages[i]->realHeight >= FLOAT_TO_LONG(float(height) * ratio)) && (subImages[i]->realWidth >= FLOAT_TO_LONG(float(width) * ratio)))
         break;
-        
+
     // compute the coordinates in the choosed sub image
     if (i) {
       x1 >>= i; y1 >>= i;
       x0 >>= i; y0 >>= i;
-      ratio *= (float) (pow(2,i));
+      ratio *= (float) (pow(2,(double) i));
     }
-    
+
     // read the rectangle in the correct sub image
     return subImages[i]->ReadSampledRectangle(x0, y0,x1, y1, map, pixelsPerLine, mapWidth, mapHeight, showAlphaChannel, ratio);
   }
@@ -1090,18 +1090,18 @@ FPXStatus PHierarchicalImage::ReadSampledRectangle(long x0, long y0,long x1, lon
 //  ----------------------------------------------------------------------------
 // Search the top and left corner of the screen pixel which contains the given position
 // This function is used when 1 image pixel is represented by more than 1 screen pixel
-FPXStatus PHierarchicalImage::SearchPixelTopLeftCorner(long* x1, long* y1, float ratio)
+FPXStatus PHierarchicalImage::SearchPixelTopLeftCorner(int* x1, int* y1, float ratio)
 {
   if (nbSubImages) {
     long i;
     for (i = nbSubImages-1; i>0; --i)
       if ((subImages[i]->realHeight >= FLOAT_TO_LONG(float(height) * ratio)) && (subImages[i]->realWidth >= FLOAT_TO_LONG(float(width) * ratio)))
         break;
-        
+
     // compute the coordinates in the choosed sub image
-    if (i) 
-      ratio *= (float) (pow(2,i));
-      
+    if (i)
+      ratio *= (float) (pow(2,(double) i));
+
     // read the rectangle in the correct sub image
     return subImages[i]->SearchPixelTopLeftCorner(x1, y1, ratio);
   }
@@ -1110,33 +1110,33 @@ FPXStatus PHierarchicalImage::SearchPixelTopLeftCorner(long* x1, long* y1, float
 
 
 //  ----------------------------------------------------------------------------
-// Compute histogram for the 4 channels 
-FPXStatus PHierarchicalImage::GetHistogram (long* alpha, long* red, long* green, long* blue, long* brightness, const CorrectLut* correctLut)
+// Compute histogram for the 4 channels
+FPXStatus PHierarchicalImage::GetHistogram (int* alpha, int* red, int* green, int* blue, int* brightness, const CorrectLut* correctLut)
 {
   FPXStatus status = FPX_OK;
-  
+
   if (Status() == 0 && nbSubImages)
     // Compute only on the last sub-image
     status = subImages[nbSubImages-1]->GetHistogram (alpha, red, green, blue, brightness, correctLut);
   else
     status = FPX_ERROR;
-  
+
   return status;
 }
 
 //  ----------------------------------------------------------------------------
 // Make a sub resolution level in create mode
-PResolutionLevel* PHierarchicalImage::CreateEmptyResolutionLevel(long , long , long* )
+PResolutionLevel* PHierarchicalImage::CreateEmptyResolutionLevel(int , int , int*)
 {
   return NULL;
-} 
+}
 
 //  ----------------------------------------------------------------------------
 // Make a sub resolution level in read or write mode
-PResolutionLevel* PHierarchicalImage::CreateInitResolutionLevel(long* , long )
+PResolutionLevel* PHierarchicalImage::CreateInitResolutionLevel(int* , long int)
 {
   return NULL;
-} 
+}
 
 //  ----------------------------------------------------------------------------
 // Make a resolution list in read or write mode and initialize it
@@ -1144,23 +1144,23 @@ PResolutionLevel* PHierarchicalImage::CreateInitResolutionLevel(long* , long )
 FPXStatus PHierarchicalImage::CreateInitResolutionLevelList()
 {
   return FPX_OK;
-} 
+}
 
 //  ----------------------------------------------------------------------------
 // Make a resolution list in create mode
 FPXStatus PHierarchicalImage::CreateEmptyResolutionLevelList()
 {
   return FPX_OK;
-} 
+}
 
 //  ----------------------------------------------------------------------------
 // Create the "subImages" array of pointers according to the "firstSubImage" list
 FPXStatus PHierarchicalImage::InitResolutionLevelsTable()
-{ 
+{
   PResolutionLevel* img;
   long i;
-  
-  // if (nbSubImages == 0) -> the PHierarchicalImage is invalid or impossible to open 
+
+  // if (nbSubImages == 0) -> the PHierarchicalImage is invalid or impossible to open
   if (nbSubImages) {
     subImages = new PResolutionLevel*[nbSubImages];
     if (subImages)
@@ -1180,7 +1180,7 @@ FPXStatus PHierarchicalImage::InitResolutionLevelsTable()
 
 
 //  ----------------------------------------------------------------------------
-//  External functions used by C code : 
+//  External functions used by C code :
 //  This is the interface of the Standard Toolkit
 //  ----------------------------------------------------------------------------
 static Boolean DeleteGlobalArrays ()
@@ -1191,7 +1191,7 @@ static Boolean DeleteGlobalArrays ()
 
 //  ----------------------------------------------------------------------------
 Boolean DemandeMemoireUrgente (long , long size)
-{ 
+{
 #ifdef Memoire_Debug
   // FOR DEBUG PURPOSE
   VISU2 "ENTER IN DEMANDEMEMOIREURGENTE()\n" FIN
@@ -1205,30 +1205,30 @@ Boolean DemandeMemoireUrgente (long , long size)
   Boolean aPurgeCompress    = false;
   long  amountNowFree;
   long  remain = size;
-  
+
   // Free any tiles not accessed within the last 5 minutes. The hope is that this will
   //  free-up clumps of blocks (i.e., tiles) from a resolution no longer being displayed, etc.
   PTile::FreeAncientBuffers( 2);
   GtheSystemToolkit->AvailableMemory (&amountNowFree);
-  
+
   // For each iteration of the folowing loop, free the oldest, unlocked buffer used to hold
   //  a tile's 'pixels' or 'rawPixels'
   PTile *foundTile;
   long  isRawPixelsBuffer;
-  
+
   while ((amountNowFree < size)
    &&   (PTile::FindOldestTileBuffer( &foundTile, &isRawPixelsBuffer) == 0)) {
     if (isRawPixelsBuffer)
       foundTile->FreeRawPixelsBuffer( );
-    else 
+    else
       foundTile->FreePixelsBuffer( );
-      
+
     GtheSystemToolkit->AvailableMemory (&amountNowFree);
   }
 
   if (amountNowFree > size)
     return true;
-  
+
   // Still need more. Purge unlocked image blocks
   PTile::Purge(&remain, 0);
   aPurgeImage = (remain != size ? true : false);
@@ -1241,14 +1241,14 @@ Boolean DemandeMemoireUrgente (long , long size)
     aPurgeLockedImage = (remain != size ? true : false);
   }
   aPurge = aPurge || aPurgeLockedImage;
-  
+
   // Delete global arrays if nothing else to purge
   if (!aPurge)
     aPurgeCompress = DeleteGlobalArrays ();
   aPurge = aPurgeCompress || aPurge;
-  
+
 #ifdef Memoire_Debug
-  // FOR DEBUG PURPOSE 
+  // FOR DEBUG PURPOSE
   if (aPurgeImage) {
     VISU2 "Image purged\n" FIN
       } else {
